@@ -102,59 +102,3 @@ setMethod("logLik",
               object@loglik
           })
 
-##' Plots the estimated survival function with an option to plot the posterior draws or bootstraps behind the fit
-##' 
-##' @param x \code{cd.fit} or \code{cd.fit.mcmc} object
-##' @param y unused
-##' 
-##' @param col.main color for plotting the main estimate
-##' 
-##' @param col.samps color for the samples (should include some alpha transparency)
-##' 
-##' @param plot.n.samps how many posterior or bootstrap samples do you want to plot?
-##' 
-##' @param add add to existing plot?
-##' 
-##' @param xlim xlim for plot, defaults to the range of the data slot in x
-##' 
-##' @param ... other options to pass to plot
-##' @rdname plot-methods
-##' @aliases plot plot,cd.fit-method
-##' @importFrom graphics plot
-##' @exportMethod plot
-setMethod("plot",
-          "cd.fit",
-          function(x,y,
-                   col.main=rgb(230, 85, 13,maxColorValue=255),
-                   col.samps=rgb(99,99,99,10,maxColorValue=255),
-                   plot.n.samps=200,
-                   add=F, xlim=range(x@data),
-                   ...) {
-
-              par1 <- x@ests[1,1]
-              par2 <- x@ests[2,1]
-
-              ## which samples do we want to plot
-              if (nrow(x@samples) > 0){
-                  plot.samples <- x@samples[sample(nrow(x@samples),min(plot.n.samps,nrow(x@samples))),]
-              }
-
-              xs <-seq(xlim[1],xlim[2],length=100)
-              if (!add) plot(-100,-100,xlim=xlim,ylim=c(0,1),...)
-              if (x@dist == "L"){
-                  if (plot.n.samps> 0 & nrow(x@samples) > 0){
-                      apply(plot.samples,1,function(y) lines(xs,plnorm(xs,meanlog=y[1],sdlog=y[2]),col=col.samps))
-                  }
-                  lines(xs,plnorm(xs,meanlog=par1,sdlog=par2),col=col.main,lwd=2)
-              } else if (x@dist == "G" | x@dist == "E"){
-                  if (plot.n.samps > 0 & nrow(x@samples) > 0){
-                      apply(plot.samples,1,function(y) lines(xs,pgamma(xs,shape=y[1],scale=y[2]),col=col.samps))
-                  }
-                  lines(xs,pgamma(xs,shape=par1,scale=par2),col=col.main,lwd=2)
-              } else if (x@dist == "W"){
-                  if (plot.n.samps > 0 & nrow(x@samples) > 0){
-                      apply(plot.samples,1,function(y) lines(xs,pweibull(xs,y[1],y[2]),col=col.samps))
-                  }
-                  lines(xs,pweibull(xs,par1,par2),col=col.main,lwd=2)
-              }
-          })
